@@ -13,10 +13,10 @@ import sys
 from itertools import groupby
 
 from .utils import validate_args, get_must_link_threshold, generate_cannot_link, \
-    download, set_random_seed, process_fasta, split_data, get_model_path
+    set_random_seed, process_fasta, split_data, get_model_path
+from .gtdb import find_or_download_gtdb
 from .generate_coverage import generate_cov, combine_cov
 from .generate_kmer import generate_kmer_features_from_fasta
-from .semi_supervised_model import train
 from .cluster import cluster
 from .fasta import fasta_iter
 from .error import LoggingPool
@@ -68,11 +68,11 @@ def parse_args(args):
     binning = subparsers.add_parser('bin',
                                     help='Binning the contigs into bins.')
 
-    download_GTDB.add_argument('-r', '--reference-db',
+    download_GTDB.add_argument('-f', '--force',
                             required=False,
-                            help='GTDB reference file path to download(~/path). (Default: $HOME/.cache/SemiBin/mmseqs2-GTDB). If not set --reference-db, we will download GTDB to the default path.',
-                            dest='GTDB_reference',
-                            metavar='',
+                            help='Redownload GTDB even if files are found',
+                            dest='force',
+                            action='store_true',
                             default=None)
 
     training.add_argument('--data',
@@ -115,7 +115,7 @@ def parse_args(args):
     training.add_argument('--mode',
                           required=True,
                           type=str,
-                          help='[single/several] Train models from one sample or several samples (train model across several samples with single-sample binning can get better pre-trained model). '
+                          help='[single/several] Train models from one (single) or more samples (several). '
                           'In `several` mode, you must provide data, data_split, cannot, and fasta files for corresponding samples in the same order. '
                           'Note: You can only use `several` mode when performing single-sample binning. Training from several samples with multi-sample binning is not supported.',
                           dest='mode',
@@ -141,18 +141,6 @@ def parse_args(args):
                          dest='data',
                          default=None,)
 
-    binning.add_argument('--minfasta-kbs',
-                            required=False,
-                            type=int,
-                            help='minimum bin size in Kbps (Default: 200).',
-                            dest='minfasta_kb',
-                            default=200,
-                            metavar='')
-    binning.add_argument('--recluster',
-                   required=False,
-                   help='recluster bins.',
-                   dest='recluster',
-                   action='store_true', )
     binning.add_argument('--max-edges',
                    required=False,
                    type=int,
@@ -173,7 +161,8 @@ def parse_args(args):
                          default=None,
                          help='Path to the trained semi-supervised deep learning model.')
 
-    training.add_argument('-p', '--processes', '-t', '--threads',
+    for p in [training, predict_taxonomy, binning, single_easy_bin, multi_easy_bin, generate_data_single, generate_data_multi]:
+        p.add_argument('-p', '--processes', '-t', '--threads',
                    required=False,
                    type=int,
                    help='Number of CPUs used (pass the value 0 to use all CPUs, default: 0)',
@@ -182,18 +171,10 @@ def parse_args(args):
                    metavar=''
                    )
 
-    predict_taxonomy.add_argument('-p', '--processes', '-t', '--threads',
-                   required=False,
-                   type=int,
-                   help='Number of CPUs used (pass the value 0 to use all CPUs, default: 0)',
-                   dest='num_process',
-                   default=0,
-                   metavar=''
-                   )
     for p in [single_easy_bin, binning]:
         p.add_argument('--environment',
                        required=False,
-                       help='environment for the built-in model(human_gut/dog_gut/ocean).',
+                       help='Environment for the built-in model (available choices: human_gut/dog_gut/ocean).',
                        dest='environment',
                        default=None,
                        )
@@ -230,24 +211,7 @@ def parse_args(args):
                        dest='ratio',
                        default=0.05)
 
-    binning.add_argument('-p', '--processes', '-t', '--threads',
-                                     required=False,
-                                     type=int,
-                                     help='Number of CPUs used (pass the value 0 to use all CPUs, default: 0)',
-                                     dest='num_process',
-                                     default=0,
-                                     metavar=''
-                                     )
-
     for p in [single_easy_bin, multi_easy_bin, generate_data_single, generate_data_multi]:
-        p.add_argument('-p', '--processes', '-t', '--threads',
-                                     required=False,
-                                     type=int,
-                                     help='Number of CPUs used (pass the value 0 to use all CPUs, default: 0)',
-                                     dest='num_process',
-                                     default=0,
-                                     metavar=''
-                                     )
         p.add_argument('-b', '--input-bam',
                               required=True,
                               nargs='*',
@@ -257,8 +221,8 @@ def parse_args(args):
                               default=None,
                               )
 
-    for p in [single_easy_bin, multi_easy_bin, predict_taxonomy]:
-        p.add_argument('-r', '--reference-db',
+    for p in [single_easy_bin, multi_easy_bin, predict_taxonomy, download_GTDB]:
+        p.add_argument('-r', '--reference-db-data-dir', '--reference-db',
                             required=False,
                             help='GTDB reference storage path. (Default: $HOME/.cache/SemiBin/mmseqs2-GTDB/GTDB).'
                             'If not set --reference-db and SemiBin cannot find GTDB in $HOME/.cache/SemiBin/mmseqs2-GTDB/GTDB, SemiBin will download GTDB (Note that >100GB of disk space are required).',
@@ -275,7 +239,7 @@ def parse_args(args):
                             metavar=''
                             )
 
-    for p in [single_easy_bin, multi_easy_bin]:
+    for p in [binning, single_easy_bin, multi_easy_bin]:
         p.add_argument('--minfasta-kbs',
                             required=False,
                             type=int,
@@ -284,11 +248,17 @@ def parse_args(args):
                             default=200,
                             metavar='')
 
+        p.add_argument('--no-recluster',
+                           required=False,
+                           help='Do not recluster bins.',
+                           dest='no_recluster',
+                           action='store_true', )
         p.add_argument('--recluster',
-                            required=False,
-                            help='recluster bins.',
-                            dest='recluster',
-                            action ='store_true',)
+                           required=False,
+                           help='[Deprecated] Does nothing (current default is to perform clustering)',
+                           dest='recluster',
+                           action='store_true', )
+    for p in [single_easy_bin, multi_easy_bin]:
 
         p.add_argument('--epoches',
                           required=False,
@@ -331,7 +301,7 @@ def parse_args(args):
         p.add_argument('--random-seed',
                        required=False,
                        type=int,
-                       help='Random seed to reproduce results.',
+                       help='Random seed. Set it to a fixed value to reproduce results across runs. The default is that the seed is set by the system and .',
                        dest='random_seed',
                        default=None,
                        )
@@ -347,23 +317,16 @@ def parse_args(args):
     if not args:
         parser.print_help(sys.stderr)
         sys.exit()
-    return parser.parse_args(args)
+    args = parser.parse_args(args)
+    if hasattr(args, 'no_recluster'):
+        args.recluster = not args.no_recluster
+    return args
 
 
 def _checkback(msg):
     msg[1].info('Processed:{}'.format(msg[0]))
 
 
-def download_GTDB(logger,GTDB_reference):
-    GTDB_default = os.path.join(
-        os.environ['HOME'],
-        '.cache',
-        'SemiBin',
-        'mmseqs2-GTDB')
-
-    GTDB_path = GTDB_reference if GTDB_reference is not None else GTDB_default
-    download(logger, GTDB_path)
-
 
 def predict_taxonomy(logger, contig_fasta,
                      cannot_name, GTDB_reference, num_process,
@@ -379,16 +342,7 @@ def predict_taxonomy(logger, contig_fasta,
     """
     import tempfile
     num_cpu = multiprocessing.cpu_count() if num_process == 0 else num_process
-    GTDB_default = os.path.join(
-        os.environ['HOME'],
-        '.cache',
-        'SemiBin',
-        'mmseqs2-GTDB',
-        'GTDB')
-    if GTDB_reference is None:
-        if not os.path.exists(GTDB_default):
-            download(logger, GTDB_default)
-        GTDB_reference = GTDB_default
+    GTDB_reference = find_or_download_gtdb(logger, GTDB_reference, False)
 
     filtered_fasta = os.path.join(output, 'filtered.fasta')
     with open(filtered_fasta, 'wt') as out:
@@ -638,6 +592,7 @@ def training(logger, contig_fasta, num_process,
 
     model: [single/several]
     """
+    from .semi_supervised_model import train
     import pandas as pd
     binned_lengths = []
     num_cpu = multiprocessing.cpu_count() if num_process == 0 else num_process
@@ -884,7 +839,7 @@ def main():
             must_link_threshold = args.ml_threshold
 
     if args.cmd == 'download_GTDB':
-        download_GTDB(logger,args.GTDB_reference)
+        find_or_download_gtdb(logger, args.GTDB_reference, args.force)
 
     if args.cmd == 'predict_taxonomy':
         predict_taxonomy(
